==> adflow-react-native-sdk-2.0.0-beta.1.tgz: package/src/fluent-adflow-widget.tsx <==
import {
  requireNativeComponent,
  NativeEventEmitter,
  NativeModules,
  findNodeHandle,
} from 'react-native';
import React, { Component, forwardRef, type LegacyRef } from 'react';
import packageJson from '../package.json';
import type { NativeMethods } from 'react-native';

const eventManagerEmitter = new NativeEventEmitter(
  NativeModules.AdsViewEventEmitter
);
const { FluentAdFlowSdkManager } = NativeModules;
const packageName = packageJson.name;
const packageVersion = packageJson.version;

type FluentAdFlowWidgetProps = {
  style?: {
    height?: number; // Make height optional
    [key: string]: any; // Allow additional style properties
  };
  params?: any;
  onAdShow?: (isVisible: boolean) => void;
  wrapperName?: any;
  wrapperVersion?: any;
};

export interface FluentAdFlowWidgetState {
  height: number;
  viewId: string;
  isParamsSet: boolean;
}

export class FluentAdFlowWidgetView extends Component<
  FluentAdFlowWidgetProps,
  FluentAdFlowWidgetState
> {
  private widgetInstanceRef = React.createRef<Component<FluentAdFlowWidgetProps> & Readonly<NativeMethods>>();


  // Add missing class properties
  private subscriberOnAdFlowContainerClosed: any;
  private subscriberOnAdFlowContainerShow: any;
  private subscriberOnAdFlowContainerHeightChanged: any;
  private subscriberOnError: any;

  constructor(props: FluentAdFlowWidgetProps) {
    super(props);
    this.state = {
      height: 0,
      viewId: Date.now() + '' + Math.floor(Math.random() * 1000000), // Unique viewId per instance
      isParamsSet: false,
    };
  }

  // Set up event listeners inside componentDidMount
  componentDidMount() {
    this.subscriberOnAdFlowContainerClosed = eventManagerEmitter.addListener(
      'onAdFlowContainerClosed',
      (viewId) => {
        // Check if the viewId matches before calling the callback
        if (String(viewId).trim() === String(this.state.viewId).trim()) {
          if (this.props.onAdShow) {
            this.props.onAdShow(false);
          }
          this.setState({ height: 0 });
          this.setState({ isParamsSet: false });
        }
      }
    );

    this.subscriberOnAdFlowContainerShow = eventManagerEmitter.addListener(
      'onAdFlowContainerShow',
      (viewId) => {
        // Check if the viewId matches before calling the callback
        if (String(viewId).trim() === String(this.state.viewId).trim()) {
          if (this.props.onAdShow) {
            this.props.onAdShow(true);
          }
          this.setState({ height: this.props.style?.height || 0 });
        }
      }
    );

    this.subscriberOnAdFlowContainerHeightChanged =
      eventManagerEmitter.addListener(
        'onAdFlowContainerHeightChanged',
        (result) => {
          const resArry = result.split('$');
          if (resArry.length > 1) {
            const viewId = resArry[0];
            const height = resArry[1];
            if (String(viewId).trim() === String(this.state.viewId).trim()) {
              this.setState({ height: parseFloat(height) });
            }
          }
        }
      );

    this.subscriberOnError = eventManagerEmitter.addListener(
      'onError',
      (viewId) => {
        if (String(viewId).trim() === String(this.state.viewId).trim()) {
          this.setState({ height: 0 });
          this.setState({ isParamsSet: false });
        }
      }
    );
  }

  // External method to set params
  setParams = (params: any) => {
    if (this.widgetInstanceRef) {
      const updatedParams = { ...params, viewId: this.state.viewId };
      const viewId = findNodeHandle(this.widgetInstanceRef.current);

      if (FluentAdFlowSdkManager && viewId) {
        FluentAdFlowSdkManager.setParams(viewId, updatedParams);
      }

      // Update state using setState
      this.setState({ isParamsSet: true });
    }
  };

  // Properly remove event listeners in componentWillUnmount
  componentWillUnmount() {
    this.subscriberOnAdFlowContainerClosed?.remove();
    this.subscriberOnAdFlowContainerShow?.remove();
    this.subscriberOnAdFlowContainerHeightChanged?.remove();
    this.subscriberOnError?.remove();
  }

  render() {
    return (
      <WidgetNativeComponent
        ref={this.widgetInstanceRef}
        style={[this.props.style, { height: this.state.height }]}
        wrapperName={packageName}
        wrapperVersion={packageVersion}
      />
    );
  }
}

const NativeAdView = requireNativeComponent<FluentAdFlowWidgetProps>(
  'FluentAdFlowWidgetView'
);

// Forward the ref to the native component
const WidgetNativeComponent = forwardRef<
  (Component<FluentAdFlowWidgetProps> & Readonly<NativeMethods>) | null,
  FluentAdFlowWidgetProps
>((props, ref) => {
  return (
    <NativeAdView
      {...props}
      ref={
        ref as LegacyRef<
          Component<FluentAdFlowWidgetProps> & Readonly<NativeMethods>
        >
      }
    />
  );
});

export default FluentAdFlowWidgetView;

==> adflow-react-native-sdk-2.0.10-beta.1.tgz: package/src/fluent-adflow-widget.tsx <==
import {
  requireNativeComponent,
  NativeEventEmitter,
  NativeModules,
  findNodeHandle,
} from 'react-native';
import React, { Component, forwardRef, type LegacyRef } from 'react';
import type { NativeMethods } from 'react-native';
import { packageName, packageVersion } from '../src/version';

const eventManagerEmitter = new NativeEventEmitter(
  NativeModules.AdsViewEventEmitter
);
const { FluentAdFlowSdkManager } = NativeModules;

type FluentAdFlowWidgetProps = {
  style?: {
    height?: number; // Make height optional
    [key: string]: any; // Allow additional style properties
  };
  params?: any;
  onAdShow?: (isVisible: boolean) => void;
  onInternalAdLaunched?: (isAdLaunched: boolean) => void;
  wrapperName?: any;
  wrapperVersion?: any;
  isScrollingEnabled?: boolean;
};

export interface FluentAdFlowWidgetState {
  height: number;
  viewId: string;
  isParamsSet: boolean;
}

export class FluentAdFlowWidgetView extends Component<
  FluentAdFlowWidgetProps,
  FluentAdFlowWidgetState
> {
  private widgetInstanceRef = React.createRef<
    Component<FluentAdFlowWidgetProps> & Readonly<NativeMethods>
  >();

  // Add missing class properties
  private subscriberOnAdFlowContainerClosed: any;
  private subscriberOnAdFlowContainerShow: any;
  private subscriberOnAdFlowContainerHeightChanged: any;
  private subscriberOnError: any;
  private subscriberOnInternalAdShown: any;
  private subscriberOnInternalAdClosed: any;

  constructor(props: FluentAdFlowWidgetProps) {
    super(props);
    this.state = {
      height: 0,
      viewId: Date.now() + '' + Math.floor(Math.random() * 1000000), // Unique viewId per instance
      isParamsSet: false,
    };
  }

  // Set up event listeners inside componentDidMount
  componentDidMount() {
    this.subscriberOnAdFlowContainerClosed = eventManagerEmitter.addListener(
      'onAdFlowContainerClosed',
      (viewId) => {
        // Check if the viewId matches before calling the callback
        if (String(viewId).trim() === String(this.state.viewId).trim()) {
          if (this.props.onAdShow) {
            this.props.onAdShow(false);
          }
          this.setState({ height: 0 });
          this.setState({ isParamsSet: false });
        }
      }
    );

    this.subscriberOnAdFlowContainerShow = eventManagerEmitter.addListener(
      'onAdFlowContainerShow',
      (viewId) => {
        // Check if the viewId matches before calling the callback
        if (String(viewId).trim() === String(this.state.viewId).trim()) {
          if (this.props.onAdShow) {
            this.props.onAdShow(true);
          }
          this.setState({ height: this.props.style?.height || 0 });
        }
      }
    );

    this.subscriberOnAdFlowContainerHeightChanged =
      eventManagerEmitter.addListener(
        'onAdFlowContainerHeightChanged',
        (result) => {
          const resArry = result.split('$');
          if (resArry.length > 1) {
            const viewId = resArry[0];
            const height = resArry[1];
            if (String(viewId).trim() === String(this.state.viewId).trim()) {
              this.setState({ height: parseFloat(height) });
            }
          }
        }
      );

    this.subscriberOnError = eventManagerEmitter.addListener(
      'onError',
      (viewId) => {
        if (String(viewId).trim() === String(this.state.viewId).trim()) {
          this.setState({ height: 0 });
          this.setState({ isParamsSet: false });
        }
      }
    );

    this.subscriberOnInternalAdShown = eventManagerEmitter.addListener(
      'onInternalAdShown',
      (viewId) => {
        // Check if the viewId matches before calling the callback
        if (String(viewId).trim() === String(this.state.viewId).trim()) {
          if (this.props.onInternalAdLaunched) {
            this.props.onInternalAdLaunched(true);
          }
        }
      }
    );

    this.subscriberOnInternalAdClosed = eventManagerEmitter.addListener(
      'onInternalAdClosed',
      (viewId) => {
        // Check if the viewId matches before calling the callback
        if (String(viewId).trim() === String(this.state.viewId).trim()) {
          if (this.props.onInternalAdLaunched) {
            this.props.onInternalAdLaunched(false);
          }
        }
      }
    );
  }

  // External method to set params
  setParams = (params: any) => {
    if (this.widgetInstanceRef) {
      const updatedParams = { ...params, viewId: this.state.viewId };
      const viewId = findNodeHandle(this.widgetInstanceRef.current);

      if (FluentAdFlowSdkManager && viewId) {
        FluentAdFlowSdkManager.setParams(viewId, updatedParams);
      }

      // Update state using setState
      this.setState({ isParamsSet: true });
    }
  };

  // Properly remove event listeners in componentWillUnmount
  componentWillUnmount() {
    this.subscriberOnAdFlowContainerClosed?.remove();
    this.subscriberOnAdFlowContainerShow?.remove();
    this.subscriberOnAdFlowContainerHeightChanged?.remove();
    this.subscriberOnInternalAdShown?.remove();
    this.subscriberOnInternalAdClosed?.remove();
    this.subscriberOnError?.remove();
  }

  render() {
    return (
      <WidgetNativeComponent
        ref={this.widgetInstanceRef}
        style={[this.props.style, { height: this.state.height }]}
        wrapperName={packageName}
        wrapperVersion={packageVersion}
        isScrollingEnabled={this.props.isScrollingEnabled}
      />
    );
  }
}

const NativeAdView = requireNativeComponent<FluentAdFlowWidgetProps>(
  'FluentAdFlowWidgetView'
);

// Forward the ref to the native component
const WidgetNativeComponent = forwardRef<
  (Component<FluentAdFlowWidgetProps> & Readonly<NativeMethods>) | null,
  FluentAdFlowWidgetProps
>((props, ref) => {
  return (
    <NativeAdView
      {...props}
      ref={
        ref as LegacyRef<
          Component<FluentAdFlowWidgetProps> & Readonly<NativeMethods>
        >
      }
    />
  );
});

export default FluentAdFlowWidgetView;
